# Mock environment variables
from ez_azml import env

MOCK_DOCKER_IMAGE = "MOCK_DOCKER_IMAGE"
MOCK_DOCKER_REGISTRY = "MOCK_DOCKER_REGISTRY"
MOCK_DOCKER_TAG = "MOCK_DOCKER_TAG"
MOCK_DOCKER_USERNAME = "MOCK_DOCKER_USERNAME"
MOCK_DOCKER_PASSWORD = "MOCK_DOCKER_PASSWORD"  # noqa: S105
MOCK_AZURE_SUBSCRIPTION_ID = "MOCK_AZURE_SUBSCRIPTION_ID"
MOCK_AZURE_RESOURCE_GROUP_NAME = "MOCK_AZURE_RESOURCE_GROUP_NAME"
MOCK_AZURE_WORKSPACE = "MOCK_AZURE_WORKSPACE"

# Rebuild the dictionary using the new variables
mock_env_vars = {
    env.DOCKER_IMAGE: MOCK_DOCKER_IMAGE,
    env.DOCKER_REGISTRY: MOCK_DOCKER_REGISTRY,
    env.DOCKER_TAG: MOCK_DOCKER_TAG,
    env.DOCKER_USERNAME: MOCK_DOCKER_USERNAME,
    env.DOCKER_PASSWORD: MOCK_DOCKER_PASSWORD,
    env.AZURE_SUBSCRIPTION_ID: MOCK_AZURE_SUBSCRIPTION_ID,
    env.AZURE_RESOURCE_GROUP_NAME: MOCK_AZURE_RESOURCE_GROUP_NAME,
    env.AZURE_WORKSPACE: MOCK_AZURE_RESOURCE_GROUP_NAME,
}


# Mock env.os_field function to return environment variables
def mock_os_getenv(env_var, default=None):
    """Mocks getenv."""
    return mock_env_vars.get(env_var, default)
